# Console Utilities

This is a simple package that contains utility functions for command-line applications. Currently, this includes
functions for inputting a number, inputting a boolean (e.g. "Enter y or n:") and selecting an option from a list of
options.
